# cvi

A Python package implementing both batch and incremental cluster validity indices (CVIs).

[![Documentation Status](https://readthedocs.org/projects/cluster-validity-indices/badge/?version=latest)](https://cluster-validity-indices.readthedocs.io/en/latest/?badge=latest)
[![Documentation Status](https://readthedocs.org/projects/cluster-validity-indices/badge/?version=develop)](https://cluster-validity-indices.readthedocs.io/en/develop/?badge=develop)
[![GitHub issues](https://img.shields.io/github/issues/AP6YC/cvi?style=flat-square)](https://github.com/AP6YC/cvi/issues)
[![GitHub stars](https://img.shields.io/github/stars/AP6YC/cvi?style=flat-square)](https://github.com/AP6YC/cvi/stargazers)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/AP6YC/cvi?style=flat-square)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/AP6YC/cvi/Test?style=flat-square)

- [cvi](#cvi)
  - [Installation](#installation)
  - [History](#history)
  - [Usage](#usage)
  - [Credits](#credits)
  - [Related Projects](#related-projects)

## Installation

```python
pip install cvi
```

## History

- 8/18/2022: Initialize project.

## Usage

TODO

## Credits

- Authors:
  - Sasha Petrenko <sap625@mst.edu>
  - Nik Melton <nmmz76@mst.edu>

## Related Projects

- [https://github.com/crew102/validclust](validclust)
- [https://github.com/Nuno09/clusterval](clusterval)
